/*
 * Action - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "action.h"
#include "../plugins/plugin_change.h"
#include "../plugins/plugin_half.h"
#include "../plugins/plugin_retry.h"
#include "../plugins/plugin_skip.h"
#include "../plugins/plugin_statistics.h"
#include "../plugins/plugin_system.h"
#include "../plugins/plugin_timer.h"

#include "gettext.h"




namespace quimeleon {





Action::Action(Configuration* configuration, Control* control)
{
}



void
Action::initialize(Configuration* configuration, Control* control)
{
	const std::vector<std::string>& plugins = configuration->plugins();
	for (std::vector<std::string>::const_iterator i = plugins.begin();
	     i < plugins.end(); i++) {
		if (find(*i) != end()) {
			continue;
		}

		if (*i == "pluginchange") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginChange(control)));
		} else if (*i == "pluginhalf") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginHalf(control)));
		} else if (*i == "pluginretry") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginRetry(control)));
		} else if (*i == "pluginskip") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginSkip(control)));
		} else if (*i == "pluginstatistics") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginStatistics(control)));
		} else if (*i == "pluginsystem") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginSystem(control)));
		} else if (*i == "plugintimer") {
			insert(std::pair<std::string, Plugin*>(
			       	*i, new quimeleon_plugin::PluginTimer(control)));
		} else {
			std::cerr << *i << ' ' << _(" not available") << '\n';
		}
	}
}



void
Action::reinitialize(Configuration* configuration, Control* control)
{
	clear();
	initialize(configuration, control);
}





} // end namespace quimeleon
