/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_AUDIO_H
#define QUIMELEON_AUDIO_H


#include <glibmm/ustring.h>

#include "config.h"

#ifdef HAVE_SOUND

# include <map>
# include <glibmm/thread.h>
# include <vorbis/vorbisfile.h>
# include <ao/ao.h>

#endif




namespace quimeleon {





class Audio
{
public:
	Audio();
	~Audio();

	void reset();


	enum audio_t {
		unknown = 0,
		question_new,
		action_select,
		answer_select,
		answer_wrong,
		answer_correct,
		outro_win,
		outro_lose
	};

	bool play(audio_t audio);
	static bool play(const Glib::ustring& filename);
	static void mute();

	void set_sound(audio_t audio, Glib::ustring file);

#ifdef HAVE_SOUND
protected:
	static bool load_file(const Glib::ustring& filename) throw();
	static void play_thread();


private:
	std::map<audio_t, Glib::ustring> _audio_files;

	static int _driver;
	static ao_device *_device;

	static int _channels;
	static int _rate;

	static OggVorbis_File _oggvorbis_file;

	static Glib::Thread* _thread;

	static bool _is_thread_running;
	static bool _is_oggvorbis;

	static Glib::Mutex _mutex_common_data;
	static int _initialized;
#endif
};





} // end namespace quimeleon




#endif
