/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include <iostream>

#include "display.h"

#include "item_answer.h"
#include "item_action.h"
#include "item_level.h"




namespace quimeleon {





Display::Display(ItemTop* top)
	: _top(top),
	  _do_full_expose(false),
	  _doing_full_expose(false)
{
	Item::set_pango_context(Gtk::Widget::create_pango_context());

	_top->connect_signal_expose(sigc::slot<void, int, int, int, int>(
			sigc::mem_fun(*this, &Display::on_changed)));
}




void
Display::set_item_top(ItemTop* top)
{
	_top = top;

	_top->set_drawable(get_window());
	_top->set_parent_dimensions(0, 0, get_width(), get_height());
	_top->draw(0, 0, get_width(), get_height(), true);

	_top->connect_signal_expose(sigc::slot<void, int, int, int, int>(
		sigc::mem_fun(*this, &Display::on_changed)));
}



bool
Display::do_full_expose()
{
	_top->draw(0, 0, get_width(), get_height(), true);
	_do_full_expose = false;
	_doing_full_expose = false;

	return false;
}



bool
Display::on_configure_event(GdkEventConfigure* event)
{
	_top->set_drawable(get_window());
	_top->set_parent_dimensions(0, 0, get_width(), get_height());
	_do_full_expose = true;


	return true;
}



bool
Display::on_expose_event(GdkEventExpose* event)
{
	if (_do_full_expose) {
// avoid consecutive complete redraws
		if (! _doing_full_expose) {
			_doing_full_expose = true;
			Glib::signal_timeout().connect(
				sigc::mem_fun(*this, &Display::do_full_expose), 500);
		}
	} else {
		_top->draw(event->area.x, event->area.y,
			event->area.width, event->area.height);
	}

	return true;
}



void
Display::on_changed(int x, int y, int w, int h)
{
	_top->draw(x, y, w, h);
}





} // end namespace quimeleon
