/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2003, 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ERROR_H
#define QUIMELEON_ERROR_H

#include <exception>
#include <string>




namespace quimeleon {





class Exception : public std::exception
{
public:
	Exception(const std::string& str)
		: _what(str) {};
	~Exception() throw() {};
	inline virtual const char* what() const throw() {
		try {
			return _what.c_str();
		} catch (...) {
			return "";
		}
	};

private:
	std::string _what;
};




class FileError : public Exception
{
public:
	FileError(const std::string& str);
};




class FileNotFound : public FileError
{
public:
	FileNotFound(const std::string& str);
};




class ReadError : public FileError
{
public:
	ReadError(const std::string& str);
};




class WriteError : public FileError
{
public:
	WriteError(const std::string& str);
};



class CreateError : public FileError
{
public:
	CreateError(const std::string& str);
};



class ParserError : public Exception
{
public:
	ParserError(const std::string& str);
};




class ParserTriviaError : public ParserError
{
public:
	ParserTriviaError(const std::string& str);
};




class ParserStyleError : public ParserError
{
public:
	ParserStyleError(const std::string& str);
};




class InvalidId : public ParserStyleError
{
public:
	InvalidId(const std::string& str);
};




class MissingItem : public ParserStyleError
{
public:
	MissingItem(const std::string& str);
};




class AttributeEmpty : public ParserStyleError
{
public:
	AttributeEmpty(const std::string& str);
};




class AttributeInvalid : public ParserStyleError
{
public:
	AttributeInvalid(const std::string& str);
};




class LayoutError : public Exception
{
public:
	LayoutError(const std::string& str);
};




class ProgramError : public Exception
{
public:
	ProgramError(const std::string& str);
};





} // end namespace quimeleon




#endif
