/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "item_answer.h"

#include "item_area.h"

#include "gettext.h"




namespace quimeleon {





ItemAnswer::ItemAnswer(const Item* parent,
	const Glib::ustring& id, item_type_t type, int number)
	: ItemMulti(parent, id, type, number),
	  _text_item(0),
	  _image_item(0),
	  _is_used(true)
{
}




void
ItemAnswer::complete_attributes()
{
	_text_item = dynamic_cast<ItemLabel*>(find_type(T_varlabel));
	_image_item = dynamic_cast<ItemPixmap*>(find_type(T_varpixmap));

	if (_text_item) {
		if (_image_item) {
			_answer_type = AT_both;
		} else {
			_answer_type = AT_text;
		}
	} else if (_image_item) {
		_answer_type = AT_image;
	} else {
		throw ParserStyleError(_("answer without text or image"));
	}

	ItemRect::complete_attributes();
}



void
ItemAnswer::set_text_and_image(const Glib::ustring& text,
	const Glib::ustring& image, bool do_compose)
{
	_text = text;
	_image = image;

	if (_text_item) {
		_text_item->set_text(text);
	}

	if (_image_item) {
		if (! _image.empty()) {
			_image_item->set_all(image);
			_image_item->set_visible(true);
		} else {
			_image_item->set_visible(false);
		}
	}

	if (   do_compose
	    && restore_pixbuf()) {
		ItemRect::compose_pixbuf();

		signal_expose();
	}
}



void
ItemAnswer::mark_state(state_t new_state, bool do_compose)
{
	if (new_state == state()) {
		return;
	}

	set_state_rec(new_state);

	if (   do_compose
	    && restore_pixbuf()) {
		ItemRect::compose_pixbuf();

		signal_expose();
	}
}



const std::vector<ItemAnswer*>&
ItemAnswer::answers() const
{
	if (_answers.empty()) {
		if (preferred_type() == _answer_type) {
			_answers.push_back(const_cast<ItemAnswer*>(this));
		} else if (_is_used) {
			_is_used = false;
		}
	}

	return _answers;
}



void
ItemAnswer::compose_pixbuf()
{
	if (_is_used) {
		ItemMulti::compose_pixbuf();
	}
}





} // end namespace quimeleon
