/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "item_area.h"




namespace quimeleon {





ItemArea::ItemArea(const Item* parent,
	const Glib::ustring& id, item_type_t type, bool is_visible)
	: ItemFunc(parent, id, type)
{
	set_visible(is_visible);
}



void
ItemArea::show()
{
	if (! visible()) {
		set_visible(true);
		if (! _pixbuf) {
			return;
		}
		compose_pixbuf();
	} else {
		if (! _pixbuf) {
			return;
		}
		restore_pixbuf();
		ItemRect::compose_pixbuf();
	}

	signal_expose();
}



void
ItemArea::redraw()
{
	restore_pixbuf();

	ItemRect::compose_pixbuf();
	signal_expose();
}



void
ItemArea::hide()
{
	if (visible()) {
		set_visible(false);

		if (restore_pixbuf()) {
			signal_expose();
		}
	}
}




const std::map<const Glib::ustring, ItemArea*>&
ItemArea::areas() const
{
	if (_areas.empty()) {
		_areas.insert(std::pair<const Glib::ustring, ItemArea*>(
			id(), const_cast<ItemArea*>(this)));
	}

	return _areas;
}





} // end namespace quimeleon
