/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "item_label.h"




namespace quimeleon {





ItemLabel::ItemLabel(const Item* parent,
	const Glib::ustring& id, item_type_t type)
	: Item(parent, id, type),
	  _alignment(align_left),
	  _parse(false)
{
}




void
ItemLabel::complete_attributes()
{
	if (_font_normal.empty()) { _font_normal = "Sans 12"; }
	if (_font_selected.empty()) { _font_selected = _font_normal; }
	if (_font_active.empty()) { _font_active = _font_normal; }
	if (_font_prelight.empty()) { _font_prelight = _font_normal; }
	if (_font_inactive.empty()) { _font_inactive = _font_normal; }
	if (_font_insensitive.empty()) { _font_insensitive = _font_normal; }

	_text = content();

	Item::complete_attributes();
}



void
ItemLabel::set_parse_arg(int label_number)
{
	std::ostringstream ostr;
	ostr << label_number;

	_text_generated = _text;
	Glib::ustring::size_type i = _text_generated.find("%d");
	while (i != Glib::ustring::npos) {
		_text_generated.replace(i, 2, ostr.str());
		i = _text_generated.find("%d", i + 1);
	}
	i = _text_generated.find("%#");
	while (i != Glib::ustring::npos) {
		if (i + 2 >= _text_generated.length()) {
			break;
		}
		Glib::ustring::value_type ch
			= _text_generated[i + 2] + label_number - 1;
		_text_generated.replace(i, 3, 1, ch);
		i = _text_generated.find("%#", i + 2);
	}
}



const Glib::ustring&
ItemLabel::font() const throw()
{
	switch (state()) {
	case selected:
		return _font_selected;
	case active:
		return _font_active;
	case prelight:
		return _font_prelight;
	case inactive:
		return _font_inactive;
	case insensitive:
		return _font_insensitive;
	case normal:
	default:
		return _font_normal;
	}
}



const Glib::ustring&
ItemLabel::text() const throw()
{
	if (parse()) {
		return _text_generated;
	}

	return _text;
}



void
ItemLabel::compose_pixbuf()
{
	if (   ! visible()
	    || crop_width() <= 0
	    || crop_height() <= 0
	    || ! _pixbuf) {
		return;
	}

	if (alpha() > 0) {
		Glib::RefPtr<Gdk::Drawable> drawable = Gdk::Pixmap::create(
			get_drawable(), width(), height(), -1);
		Glib::RefPtr<Gdk::Colormap> colormap = drawable->get_colormap();

		Gdk::Color fg_color;
		fg_color.set_rgb(r(), g(), b());
		fg_color.rgb_find_color(colormap);
		gc()->set_foreground(fg_color);
		Glib::RefPtr<Pango::Layout> layout
			= Pango::Layout::create(pango_context());
		Pango::FontDescription font_description
			= Pango::FontDescription(font());
		font_description.set_size(
			int(font_scale() * font_description.get_size()));
		layout->set_width(width() * 1000);
		layout->set_font_description(font_description);
		layout->set_text(text());
		if (_alignment == align_justify) {
			layout->set_justify(true);
		} else {
			layout->set_alignment(Pango::Alignment(_alignment));
		}
		int layout_width;
		int layout_height;
		layout->get_pixel_size(layout_width, layout_height);
		if (layout_height > height()) {
			font_description.set_size(font_description.get_size()
				* height() / (layout_height));
			layout->set_font_description(font_description);
			layout->get_pixel_size(layout_width, layout_height);
		}


		drawable->draw_pixbuf(gc(), _pixbuf,
			crop_x(), crop_y(),
			crop_x() - x(), crop_y() - y(),
			crop_width(), crop_height(),
			Gdk::RGB_DITHER_NORMAL ,
			x(), y());
		drawable->draw_layout(gc(), 0, (height() - layout_height) / 2, layout);


		Glib::RefPtr<Gdk::Pixbuf> pixbuf
			= Gdk::Pixbuf::create(drawable, colormap,
				crop_x() - x(), crop_y() - y(),
				0, 0, crop_width(), crop_height());

		pixbuf->composite(_pixbuf,
			crop_x(), crop_y(), crop_width(), crop_height(),
			crop_x(), crop_y(), 1, 1,
			Gdk::INTERP_BILINEAR, alpha());
	}

	Item::compose_pixbuf();
}





} // end namespace quimeleon
