/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ITEM_PIXMAP_H
#define QUIMELEON_ITEM_PIXMAP_H

#include <map>

#include "item.h"




namespace quimeleon {





class ItemPixmap : public Item
{
public:
	ItemPixmap(const Item* parent = 0,
		const Glib::ustring& id = "", item_type_t type = T_pixmap,
		bool keep_aspect = false,
		bool do_buffer = false);

	void complete_attributes();
	void set_parent_dimensions(int x, int y, int width, int height,
		int crop_x, int crop_y, int crop_width, int crop_height);



	inline void set_normal(Glib::ustring filename)
	{
		_normal = filename;
	}

	inline void set_selected(Glib::ustring filename)
	{
		_selected = filename;
	}

	inline void set_active(Glib::ustring filename)
	{
		_active = filename;
	}

	inline void set_prelight(Glib::ustring filename)
	{
		_prelight = filename;
	}

	inline void set_inactive(Glib::ustring filename)
	{
		_inactive = filename;
	}

	inline void set_insensitive(Glib::ustring filename)
	{
		_insensitive = filename;
	}

	inline void set_all(Glib::ustring filename)
	{
		_normal = _selected = _active = _prelight = _inactive = _insensitive
			= filename;
	}

	inline void set_do_buffer(bool do_buffer = true) throw()
	{
		_do_buffer = do_buffer;
	}


protected:
	void compose_pixbuf();


private:
	static std::map<const Glib::ustring, std::map<std::pair<int, int>, Glib::RefPtr<Gdk::Pixbuf> > > _pixbufs;

private:
	Glib::ustring _normal;
	Glib::ustring _selected;
	Glib::ustring _active;
	Glib::ustring _prelight;
	Glib::ustring _inactive;
	Glib::ustring _insensitive;

	const bool _keep_aspect;
	bool _do_buffer;
	int _pixbuf_w;
	int _pixbuf_h;
};





} // end namespace quimeleon




#endif
