/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "item_question.h"

#include "gettext.h"




namespace quimeleon {




ItemQuestion::ItemQuestion(const Item* parent,
	const Glib::ustring& id, item_type_t type)
	: ItemFunc(parent, id, type),
	  _text_item(0)
{
}




void
ItemQuestion::set_text(const Glib::ustring& text, bool do_compose)
{
	_text = text;

	if (! _text_item) {
		_text_item = dynamic_cast<ItemLabel*>(find_type(T_varlabel));
	}

	if (_text_item) {
		_text_item->set_text(text);
	} else {
		std::cerr << _("No item of type \"text\" in question box") << '\n';
	}

	if (   do_compose
	    && restore_pixbuf()) {
		ItemRect::compose_pixbuf();

		signal_expose();
	}
}



ItemQuestion*
ItemQuestion::question() const throw()
{
	if (! _question) {
		_question = const_cast<ItemQuestion*>(this);
	}

	return _question;
}





} // end namespace quimeleon
