/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ITEM_STATUS_H
#define QUIMELEON_ITEM_STATUS_H

#include "error.h"

#include "item_multi.h"



namespace quimeleon {





class ItemStatus : public ItemMulti
{
public:
	enum reference_t {
		R_none = 0,
		R_level,
		R_question,
		R_next_level,
		R_next_question,
		R_next_level_and_question,
		R_manual
	};


public:
	ItemStatus(Item* parent = 0,
		const Glib::ustring& id = "", item_type_t type = T_rect,
		int number = -1,
		reference_t reference = R_none);

	void complete_attributes();

	void set_level(unsigned int n);
	void set_question(unsigned int n);
	void next_level();
	void next_question();
	void set_manual(unsigned int number, unsigned int n);
	void next_manual(unsigned int number);
	void prev_manual(unsigned int number);

	void reset();

	inline void add_child(Item* child)
	{
		add_filler(child);
		ItemRect::add_child(child);
	}
	inline void add_filler(Item* filler)
	{
		if (parse_alternatives()) {
			_children_and_fillers.back().push_back(filler);
		} else {
			_children_and_fillers.push_back(std::vector<Item*>(1, filler));
		}
	}

	const std::vector<ItemStatus*>& statuss() const;


private:
	void change_status();


private:
	reference_t _reference;
	unsigned int _selected;
	unsigned int _active;

	bool _is_next_level;
	bool _is_next_question;

	std::vector<std::vector<Item*> > _children_and_fillers;
};





} // end namespace quimeleon




#endif
