/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_PREFERENCES_H
#define QUIMELEON_PREFERENCES_H

#include <gtkmm/checkbutton.h>
#include <gtkmm/comboboxtext.h>
#include <gtkmm/dialog.h>
#include <gtkmm/entry.h>

#include "configuration.h"
#include "data_dirs_editor.h"




namespace quimeleon {





class Preferences : public Gtk::Dialog
{
public:
	Preferences(Gtk::Window& parent, Configuration* configuration);
	Preferences(Configuration* configuration, bool do_save = false);

	void init(bool do_save = true);

	inline bool is_new_style() const throw() { return _is_new_style; }
	inline bool is_new_trivia() const throw() { return _is_new_trivia; }

protected:
	void on_response(int response_id);

	void style_file_select();
	void trivia_file_select();

private:
	std::string find_file(const std::string& filename) const;

private:
	Configuration* _configuration;

	Gtk::Entry* _entry_trivia_file;
	Gtk::Entry* _entry_style_file;
	Gtk::ComboBoxText* _combo_box_style;
	Gtk::CheckButton* _check_button_fullscreen;
	Gtk::CheckButton* _check_button_do_buffer;
	Gtk::CheckButton* _check_button_do_show_hint;

	DataDirsEditor* _data_dirs_editor;

	std::string _old_style_name;
	std::string _old_style_file;
	std::string _old_trivia_file;

	bool _is_style_available;
	bool _is_new_style;
	bool _is_new_trivia;
};





} // end namespace quimeleon




#endif
