/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2006  Aike Reyer <aike@users.sourceforge.net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "welcome.h"

#include <gtkmm/label.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/stock.h>
#include <gtkmm/textview.h>

#include "gettext.h"




namespace quimeleon {





Welcome::Welcome()
	: Gtk::Dialog(_8("Hint")),
	  _do_show_hint_check_button(
		_8("_show this hint on next startup"), true)
{
	set_default_size(410, 253);

	Gtk::VBox* vbox = get_vbox();

	Gtk::Label* label = Gtk::manage(
		new Gtk::Label(  "<span size=\"large\" weight=\"bold\">"
		               + Glib::ustring(PACKAGE_STRING)
		               + "</span>"));
	label->set_use_markup();
	label->set_padding(2, 4);

	vbox->pack_start(*label, Gtk::PACK_SHRINK);

	Gtk::HBox* hbox = Gtk::manage(new Gtk::HBox);

	bool is_no_svg = false;
	try {
		Gtk::Image* image = Gtk::manage(
			new Gtk::Image(Gdk::Pixbuf::create_from_file(
				Glib::build_filename(ICONDIR, "quimeleon.svg"), 100, 100)));
		image->set_alignment(Gtk::ALIGN_LEFT, Gtk::ALIGN_TOP);
		hbox->pack_start(*image, Gtk::PACK_SHRINK);
	} catch (const Gdk::PixbufError& e) {
		is_no_svg = true;
	}

	Gtk::ScrolledWindow* scrolled_window = Gtk::manage(new Gtk::ScrolledWindow);
	scrolled_window->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);

	Gtk::TextView* text_view = Gtk::manage(new Gtk::TextView);
	text_view->set_editable(false);
	text_view->set_wrap_mode(Gtk::WRAP_WORD_CHAR);

	Glib::RefPtr<Gtk::TextBuffer> text_buffer = text_view->get_buffer();
	text_buffer->set_text(_8(
		  "On first startup (and as long as you do not change anything) "
		  "the Quimeleon default style and trivia questions are loaded.")
		+ "\n\n"
		+ _8(
		  "To get a quick glance at what Quimeleon can do press the space "
		  "or return key in the main window. With every press of the key "
		  "Quimeleon will advance one step.")
		+ (is_no_svg ? "\n\n" + _8(
		  "Be aware that the default style uses Scalable Vector Graphics "
		  "(SVG) and your installation must be configured to read these "
		  "graphics. However this seems not to be the case for your system.\n"
		  "Try to install the SVG loader for gdk-pixbuf (something like "
		  "librsvg2)") : "")
		);

	scrolled_window->add(*text_view);

	hbox->pack_start(*scrolled_window);

	vbox->pack_start(*hbox);


	vbox->pack_end(_do_show_hint_check_button, Gtk::PACK_SHRINK);

	vbox->show_all();

	add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
}





} // end namespace quimeleon
